======================
Spike train surrogates
======================


.. automodule:: elephant.spike_train_surrogates


References
----------

.. bibliography:: ../bib/elephant.bib
   :labelprefix: sr
   :keyprefix: surrogates-
   :style: unsrt
